pitchtools.set_default_accidental_spelling
==========================================

.. autofunction:: abjad.tools.pitchtools.set_default_accidental_spelling.set_default_accidental_spelling
   :noindex:
